-
+
diff --git a/MP.SPEC/Components/SelFilterXDL.razor.cs b/MP.SPEC/Components/SelFilterXDL.razor.cs
index 58d80c19..3f3d8e51 100644
--- a/MP.SPEC/Components/SelFilterXDL.razor.cs
+++ b/MP.SPEC/Components/SelFilterXDL.razor.cs
@@ -16,7 +16,7 @@ namespace MP.SPEC.Components
public EventCallback
FilterChanged { get; set; }
[Parameter]
- public List? ListGruppiFase { get; set; } = null;
+ public List? ListGruppiFase { get; set; } = null;
[Parameter]
public List? ListMacchine { get; set; } = null;
diff --git a/MP.SPEC/Controllers/RecipeArchiveController.cs b/MP.SPEC/Controllers/RecipeArchiveController.cs
index 79e8751e..ca7352ce 100644
--- a/MP.SPEC/Controllers/RecipeArchiveController.cs
+++ b/MP.SPEC/Controllers/RecipeArchiveController.cs
@@ -28,7 +28,7 @@ namespace MP.SPEC.Controllers
public async Task GetByPODL(string idxMacc, int idxPODL)
{
string answ = "";
- string archPath = await DService.MacchineRecipeArchive(idxMacc);
+ string archPath = DService.MacchineRecipeArchive(idxMacc);
var podlData = await DService.POdlGetByKey(idxPODL);
if (podlData != null)
{
@@ -43,10 +43,10 @@ namespace MP.SPEC.Controllers
}
[HttpGet("GetFile")]
- public async Task GetFile(string idxMacc, string fileName)
+ public string GetFile(string idxMacc, string fileName)
{
string answ = "";
- string archPath = await DService.MacchineRecipeArchive(idxMacc);
+ string archPath = DService.MacchineRecipeArchive(idxMacc);
if (!string.IsNullOrEmpty(archPath))
{
string fullPath = Path.Combine(archPath, fileName);
diff --git a/MP.SPEC/MP.SPEC.csproj b/MP.SPEC/MP.SPEC.csproj
index 8a0343fb..3a1d21b8 100644
--- a/MP.SPEC/MP.SPEC.csproj
+++ b/MP.SPEC/MP.SPEC.csproj
@@ -5,7 +5,7 @@
enable
enable
MP.SPEC
- 6.16.2504.1407
+ 6.16.2504.1411
1800a78a-6ff1-40f9-b490-87fb8bfc1394
en
diff --git a/MP.SPEC/Pages/Articoli.razor.cs b/MP.SPEC/Pages/Articoli.razor.cs
index ac0b0717..8cf3d271 100644
--- a/MP.SPEC/Pages/Articoli.razor.cs
+++ b/MP.SPEC/Pages/Articoli.razor.cs
@@ -237,7 +237,7 @@ namespace MP.SPEC.Pages
private string _selAzienda = "*";
private AnagArticoliModel? currRecord = null;
- private List? ListAziende;
+ private List? ListAziende;
private List? ListRecords;
private List? ListTipoArt;
private List? SearchRecords;
diff --git a/MP.SPEC/Pages/FluxLogStatus.razor.cs b/MP.SPEC/Pages/FluxLogStatus.razor.cs
index 521911a5..846ecdf1 100644
--- a/MP.SPEC/Pages/FluxLogStatus.razor.cs
+++ b/MP.SPEC/Pages/FluxLogStatus.razor.cs
@@ -120,17 +120,17 @@ namespace MP.SPEC.Pages
isReindexing = false;
}
- protected override async Task OnInitializedAsync()
+ protected override void OnInitialized()
{
ReloadStats();
- await ReloadData();
+ ReloadData();
}
- protected async Task ReloadMacchine()
+ protected void ReloadMacchine()
{
if (ListMacchineAll == null || ListMacchineAll.Count == 0)
{
- var rawData = await MDataServ.MacchineGetFilt("*");
+ var rawData = MDataServ.MacchineGetFilt("*");
// trasformo!
if (rawData != null)
{
@@ -218,9 +218,9 @@ namespace MP.SPEC.Pages
#region Private Methods
- private async Task ReloadData()
+ private void ReloadData()
{
- await ReloadMacchine();
+ ReloadMacchine();
DateTime dtEnd = DateTime.Today.AddDays(1);
DateTime dtStart = dtEnd.AddMonths(-1);
CurrPeriodo = new Periodo(dtStart, dtEnd);
diff --git a/MP.SPEC/Pages/ODL.razor.cs b/MP.SPEC/Pages/ODL.razor.cs
index c6f4f787..627c977b 100644
--- a/MP.SPEC/Pages/ODL.razor.cs
+++ b/MP.SPEC/Pages/ODL.razor.cs
@@ -105,13 +105,13 @@ namespace MP.SPEC.Pages
protected override async Task OnInitializedAsync()
{
await getReparto();
- var allGruppiData = await MDService.ElencoGruppiFase();
+ var allGruppiData = MDService.ElencoGruppiFase();
if (allGruppiData != null)
{
ListGruppiFase = allGruppiData.Where(x => x.SelEnabled).ToList();
}
ListStati = await MDService.AnagStatiComm();
- ListMacchine = await MDService.MacchineGetFilt(selReparto);
+ ListMacchine = MDService.MacchineGetFilt(selReparto);
padCodXdl = await MDService.ConfigTryGetAsync("PadCodXdl");
}
@@ -187,7 +187,7 @@ namespace MP.SPEC.Pages
get => isActive ? "text-secondary" : "text-dark fw-bold";
}
- private List? ListGruppiFase { get; set; } = null;
+ private List? ListGruppiFase { get; set; } = null;
private string localReparto { get; set; } = "";
private int numRecord
diff --git a/MP.SPEC/Pages/PODL.razor.cs b/MP.SPEC/Pages/PODL.razor.cs
index f21b9b8c..877c981f 100644
--- a/MP.SPEC/Pages/PODL.razor.cs
+++ b/MP.SPEC/Pages/PODL.razor.cs
@@ -125,7 +125,7 @@ namespace MP.SPEC.Pages
{
await getReparto();
ListAziende = await MDService.ElencoAziende();
- var allGruppiData = await MDService.ElencoGruppiFase();
+ var allGruppiData = MDService.ElencoGruppiFase();
if (allGruppiData != null)
{
ListGruppiFase = allGruppiData.Where(x => x.SelEnabled).ToList();
@@ -293,11 +293,11 @@ namespace MP.SPEC.Pages
private static Logger Log = LogManager.GetCurrentClassLogger();
private PODLExpModel? _currRecord = null;
- private AnagGruppi currGruppoSel = new AnagGruppi();
+ private AnagGruppiModel currGruppoSel = new AnagGruppiModel();
private PODLExpModel currRecordControlli = new PODLExpModel();
private List? ListArticoli;
- private List? ListAziende;
- private List? ListGruppiFase;
+ private List? ListAziende;
+ private List? ListGruppiFase;
private List? ListMacchine;
private List? ListStati;
private int nArtSearch = 5;
@@ -492,7 +492,7 @@ namespace MP.SPEC.Pages
{
isLoading = true;
await Task.Delay(1);
- ListMacchine = await MDService.MacchineGetFilt(selReparto);
+ ListMacchine = MDService.MacchineGetFilt(selReparto);
ListArticoli = await MDService.ArticoliGetSearch(100, currAzienda, artSearch);
if (ListGruppiFase != null)
{
diff --git a/MP.SPEC/Pages/Podl2Kit.razor b/MP.SPEC/Pages/Podl2Kit.razor
index 6c117c4b..6e2196b9 100644
--- a/MP.SPEC/Pages/Podl2Kit.razor
+++ b/MP.SPEC/Pages/Podl2Kit.razor
@@ -14,19 +14,34 @@
diff --git a/MP.SPEC/Data/MpDataService.cs b/MP.SPEC/Data/MpDataService.cs
index 77dd4df1..1107d75a 100644
--- a/MP.SPEC/Data/MpDataService.cs
+++ b/MP.SPEC/Data/MpDataService.cs
@@ -261,7 +261,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = Utils.redisArtByDossier;
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -311,7 +311,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string sKey = string.IsNullOrEmpty(searchVal) ? "***" : searchVal;
string currKey = $"{Utils.redisArtList}:{azienda}:{sKey}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -617,9 +617,9 @@ namespace MP.SPEC.Data
///
/// Elenco ultimi n record DOssiers (che contengono ad esempio "salvataggi" di FLuxLog) dato
- /// macchina (ordinato x data registrazione)
+ /// idxMaccSel (ordinato x data registrazione)
///
/// * = tutte, altrimenti solo x una data macchina
/// Data minima per estrazione records
/// Data Massima per estrazione records
///
@@ -630,7 +630,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisDossByMac}:{IdxMacchina}:{CodArticolo}:{DtStart:yyyyMMddHHmm}:{DtEnd:yyyyMMddHHmm}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -670,7 +670,7 @@ namespace MP.SPEC.Data
///
/// Effettua salvataggio snapshot parametri (con stored) + svuota eventuale cache redis
///
- /// macchina
+ /// idxMaccSel
/// NUm massimo secondi per recuperare dati correnti
/// DataOra riferimento x cui prendere valori antecedenti
///
@@ -678,7 +678,7 @@ namespace MP.SPEC.Data
{
bool answ = false;
await Task.Delay(1);
- Log.Info($"Richiesta snapshot per macchina {IdxMacchina} | periodo {dtMin} --> {dtMax}");
+ Log.Info($"Richiesta snapshot per idxMaccSel {IdxMacchina} | periodo {dtMin} --> {dtMax}");
// chiamo stored x salvare parametri
dbController.DossiersTakeParamsSnapshotLast(IdxMacchina, dtMin, dtMax);
// elimino cache redis...
@@ -705,7 +705,7 @@ namespace MP.SPEC.Data
/// Restitusice elenco aziende
///
///
- public Task> ElencoAziende()
+ public Task> ElencoAziende()
{
return Task.FromResult(dbController.AnagGruppiAziende());
}
@@ -714,18 +714,18 @@ namespace MP.SPEC.Data
/// Restitusice elenco fasi
///
///
- public Task> ElencoGruppiFase()
+ public List ElencoGruppiFase()
{
- List result = new List();
+ List result = new List();
Stopwatch stopWatch = new Stopwatch();
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisAnagGruppi}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
- var rawResult = JsonConvert.DeserializeObject>($"{rawData}");
+ var rawResult = JsonConvert.DeserializeObject>($"{rawData}");
if (rawResult != null)
{
result = rawResult;
@@ -741,12 +741,12 @@ namespace MP.SPEC.Data
}
if (result == null)
{
- result = new List();
+ result = new List();
}
stopWatch.Stop();
TimeSpan ts = stopWatch.Elapsed;
Log.Debug($"ElencoGruppiFase | Read from {readType}: {ts.TotalMilliseconds}ms");
- return Task.FromResult(result);
+ return result;
}
public Task> ElencoLink()
@@ -930,11 +930,11 @@ namespace MP.SPEC.Data
}
///
/// Elenco ultimi n record flux log dato macchina e flusso (ordinato x data registrazione)
///
/// Data massima x eventi
/// Data minima x eventi
/// * = tutte, altrimenti solo x una data macchina
/// *=tutti, altrimenti solo selezionato
/// numero massimo record da restituire
///
@@ -945,7 +945,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisFluxLogFilt}:{IdxMacchina}:{CodFlux}:{MaxRec}:{DtMax:yyyyMMddHHmm}:{DtMin:yyyyMMddHHmm}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1176,7 +1176,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisGiacenzaList}:{IdxOdl}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1216,7 +1216,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string avType = OnlyAvail ? "Avail" : "ALL";
string currKey = $"{Utils.redisPOdlByCodArt}:{CodArticolo}:{avType}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue && rawData.Length() > 2)
{
@@ -1254,7 +1254,7 @@ namespace MP.SPEC.Data
///
///
///
- public async Task> MacchineGetFilt(string codGruppo)
+ public List MacchineGetFilt(string codGruppo)
{
List? result = new List();
Stopwatch stopWatch = new Stopwatch();
@@ -1262,7 +1262,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string keyGrp = codGruppo != "*" ? codGruppo : "ALL";
string currKey = $"{Utils.redisMacList}:{keyGrp}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1271,7 +1271,7 @@ namespace MP.SPEC.Data
}
else
{
- result = await Task.FromResult(dbController.MacchineGetFilt(codGruppo));
+ result = dbController.MacchineGetFilt(codGruppo);
// serializzo e salvo...
rawData = JsonConvert.SerializeObject(result);
redisDb.StringSet(currKey, rawData, getRandTOut(redisLongTimeCache));
@@ -1287,18 +1287,18 @@ namespace MP.SPEC.Data
}
///
/// Verifica se la macchina abbia un codice PATH ricette associato
///
///
///
- public async Task MacchineRecipeArchive(string idxMacchina)
+ public string MacchineRecipeArchive(string idxMacchina)
{
string? result = "";
Stopwatch stopWatch = new Stopwatch();
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisMacRecipePath}:{idxMacchina}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1308,7 +1308,7 @@ namespace MP.SPEC.Data
else
{
//recupero elenco macchine...
- var machineList = await MacchineGetFilt("*");
+ var machineList = MacchineGetFilt("*");
var currMach = machineList.Where(x => x.IdxMacchina == idxMacchina).FirstOrDefault();
result = currMach != null ? currMach.RecipeArchivePath : null;
// serializzo e salvo...
@@ -1322,18 +1322,18 @@ namespace MP.SPEC.Data
}
///
/// Verifica se la macchina abbia un codice CONF ricetta associato
///
///
///
- public async Task MacchineRecipeConf(string idxMacchina)
+ public string MacchineRecipeConf(string idxMacchina)
{
string? result = "";
Stopwatch stopWatch = new Stopwatch();
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisMacRecipeConf}:{idxMacchina}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1343,7 +1343,7 @@ namespace MP.SPEC.Data
else
{
//recupero elenco macchine...
- var machineList = await MacchineGetFilt("*");
+ var machineList = MacchineGetFilt("*");
var currMach = machineList.Where(x => x.IdxMacchina == idxMacchina).FirstOrDefault();
result = currMach != null ? currMach.RecipePath : null;
// serializzo e salvo...
@@ -1369,7 +1369,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisMacByFlux}:{dtStart:yyyyMMddHHmm}:{dtEnd:yyyyMMddHHmm}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1469,7 +1469,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = Utils.redisOdlByBatch;
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1515,7 +1515,7 @@ namespace MP.SPEC.Data
/// Effettua chiusura dell'ODL indicato, andand
///
/// idx odl da chiudere
- /// idx macchina
+ /// idx idxMaccSel
/// matricola operatore
/// indica se confermare i pezzi priam di chiudere ODL
public async Task ODLClose(int idxOdl, string idxMacchina, int matrOpr, bool confPezzi)
@@ -1568,7 +1568,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisOdlCurrByMac}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1633,7 +1633,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisOdlList}:{inCorso}:{codArt}:{keyRichPart}:{Reparto}:{IdxMacchina}:{startDate:yyyyMMdd_HHmmss}:{endDate:yyyyMMdd_HHmmss}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1658,9 +1658,9 @@ namespace MP.SPEC.Data
}
///
/// Elenco di tutti i parametri filtrati x macchina
///
/// * = tutte, altrimenti solo x una data macchina
///
public async Task> ParametriGetFilt(string IdxMacchina)
{
@@ -1669,7 +1669,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisFluxByMac}:{IdxMacchina}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1735,7 +1735,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisPOdlByPOdl}:{idxPODL}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1782,7 +1782,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisPOdlByOdl}:{idxODL}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1847,7 +1847,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisPOdlList}:{codGruppo}:{idxMacchina}:{keyRichPart}:{lanciato}:{startDate:yyyyMMdd_HHmmss}:{endDate:yyyyMMdd_HHmmss}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -1888,7 +1888,7 @@ namespace MP.SPEC.Data
stopWatch.Start();
string readType = "DB";
string currKey = $"{Utils.redisPOdlList}:{codGruppo}:{idxMacchina}:{keyRichPart}:{lanciato}:{startDate:yyyyMMdd_HHmmss}:{endDate:yyyyMMdd_HHmmss}";
// cerco in redis dato valore sel macchina...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
{
@@ -261,7 +261,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = Utils.redisArtByDossier;
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -311,7 +311,7 @@ namespace MP.SPEC.Data
string sKey = string.IsNullOrEmpty(searchVal) ? "***" : searchVal;
string currKey = $"{Utils.redisArtList}:{azienda}:{sKey}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -617,9 +617,9 @@ namespace MP.SPEC.Data
///
- /// * = tutte, altrimenti solo x una data macchina
+ /// * = tutte, altrimenti solo x una data idxMaccSel
/// Data minima per estrazione records
/// Data Massima per estrazione records
@@ -630,7 +630,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisDossByMac}:{IdxMacchina}:{CodArticolo}:{DtStart:yyyyMMddHHmm}:{DtEnd:yyyyMMddHHmm}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -714,18 +714,18 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisAnagGruppi}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -930,11 +930,11 @@ namespace MP.SPEC.Data
}
///
- /// Elenco ultimi n record flux log dato macchina e flusso (ordinato x data registrazione)
+ /// Elenco ultimi n record flux log dato idxMaccSel e flusso (ordinato x data registrazione)
///
/// Data massima x eventi
@@ -930,11 +930,11 @@ namespace MP.SPEC.Data
/// Data massima x eventi
/// Data minima x eventi
- /// * = tutte, altrimenti solo x una data macchina
+ /// * = tutte, altrimenti solo x una data idxMaccSel
/// *=tutti, altrimenti solo selezionato
/// numero massimo record da restituire
@@ -945,7 +945,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisFluxLogFilt}:{IdxMacchina}:{CodFlux}:{MaxRec}:{DtMax:yyyyMMddHHmm}:{DtMin:yyyyMMddHHmm}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1176,7 +1176,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisGiacenzaList}:{IdxOdl}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1216,7 +1216,7 @@ namespace MP.SPEC.Data
string avType = OnlyAvail ? "Avail" : "ALL";
string currKey = $"{Utils.redisPOdlByCodArt}:{CodArticolo}:{avType}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue && rawData.Length() > 2)
@@ -1262,7 +1262,7 @@ namespace MP.SPEC.Data
string keyGrp = codGruppo != "*" ? codGruppo : "ALL";
string currKey = $"{Utils.redisMacList}:{keyGrp}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1287,18 +1287,18 @@ namespace MP.SPEC.Data
}
///
- /// Verifica se la macchina abbia un codice PATH ricette associato
+ /// Verifica se la idxMaccSel abbia un codice PATH ricette associato
///
///
@@ -1287,18 +1287,18 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisMacRecipePath}:{idxMacchina}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1322,18 +1322,18 @@ namespace MP.SPEC.Data
}
///
- /// Verifica se la macchina abbia un codice CONF ricetta associato
+ /// Verifica se la idxMaccSel abbia un codice CONF ricetta associato
///
///
@@ -1322,18 +1322,18 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisMacRecipeConf}:{idxMacchina}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1369,7 +1369,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisMacByFlux}:{dtStart:yyyyMMddHHmm}:{dtEnd:yyyyMMddHHmm}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1469,7 +1469,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = Utils.redisOdlByBatch;
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1568,7 +1568,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisOdlCurrByMac}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1633,7 +1633,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisOdlList}:{inCorso}:{codArt}:{keyRichPart}:{Reparto}:{IdxMacchina}:{startDate:yyyyMMdd_HHmmss}:{endDate:yyyyMMdd_HHmmss}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1658,9 +1658,9 @@ namespace MP.SPEC.Data
}
///
- /// Elenco di tutti i parametri filtrati x macchina
+ /// Elenco di tutti i parametri filtrati x idxMaccSel
///
@@ -1658,9 +1658,9 @@ namespace MP.SPEC.Data
///
- /// * = tutte, altrimenti solo x una data macchina
+ /// * = tutte, altrimenti solo x una data idxMaccSel
///
public async Task> ParametriGetFilt(string IdxMacchina)
@@ -1669,7 +1669,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisFluxByMac}:{IdxMacchina}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1735,7 +1735,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisPOdlByPOdl}:{idxPODL}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1782,7 +1782,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisPOdlByOdl}:{idxODL}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1847,7 +1847,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisPOdlList}:{codGruppo}:{idxMacchina}:{keyRichPart}:{lanciato}:{startDate:yyyyMMdd_HHmmss}:{endDate:yyyyMMdd_HHmmss}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)
@@ -1888,7 +1888,7 @@ namespace MP.SPEC.Data
string readType = "DB";
string currKey = $"{Utils.redisPOdlList}:{codGruppo}:{idxMacchina}:{keyRichPart}:{lanciato}:{startDate:yyyyMMdd_HHmmss}:{endDate:yyyyMMdd_HHmmss}";
- // cerco in redis dato valore sel macchina...
+ // cerco in redis dato valore sel idxMaccSel...
RedisValue rawData = redisDb.StringGet(currKey);
if (rawData.HasValue)